@@ -1,8 +1,10 @@
 #' @title Get Intersection Set for Two Sets
 #' @description Get intersection set for two sets, which can be numbers, characters, vectors even dataframe, matrix or list.
-#' @param a can be numbers, characters, vectors, one dataframe, one matrix or one list.
-#' @param b can be numbers, characters, vectors, one dataframe, one matrix or one list.
+#' @param a see argument x in \code{\link[set]{toVector}}
+#' @param b see argument x in \code{\link[set]{toVector}}
 #' @return intersection set
+#' @name and2
+#' @rdname and2
 #' @export
 #'
 #' @examples
@@ -17,5 +19,24 @@
     a=unique(a)
     b=toVector(b)
     b=unique(b)
-    COMMON(a,b)
+    a[a %in% b]
+}
+
+#' @rdname and2
+#' @export
+"%a%" <- `%and%`
+#' @rdname and2
+#' @export
+"%A%" <- `%and%`
+
+#' @rdname and2
+#' @export
+"&" <- function(a,b) {
+    check=tryCatch(expr = {base::`&`(a,b)},
+                   error=function(e) 'thiswrong')
+    if (check[1]=='thiswrong') {
+        a %and% b
+    }else{
+        check
+    }
 }
